@@ -14,7 +14,7 @@
 
 #include "bonobo-config-bag.h"
 
-#define PARENT_TYPE (BONOBO_OBJECT_TYPE)
+#define PARENT_TYPE (BONOBO_TYPE_OBJECT)
 
 #define GET_BAG_FROM_SERVANT(servant) \
 BONOBO_CONFIG_BAG (bonobo_object (servant))
@@ -289,7 +289,7 @@ bonobo_config_bag_new (Bonobo_ConfigDatabase db,
 	g_return_val_if_fail (db != NULL, NULL);
 	g_return_val_if_fail (path != NULL, NULL);
 
-	cb = g_object_new (BONOBO_CONFIG_BAG_TYPE, NULL);
+	cb = g_object_new (BONOBO_TYPE_CONFIG_BAG, NULL);
 	
 	if (path[0] == '/')
 		cb->path = g_strdup (path);
