@@ -14,11 +14,12 @@
 
 G_BEGIN_DECLS
 
-#define BONOBO_CONFIG_BAG_TYPE        (bonobo_config_bag_get_type ())
-#define BONOBO_CONFIG_BAG(o)	      (G_TYPE_CHECK_INSTANCE_CAST ((o), BONOBO_CONFIG_BAG_TYPE, BonoboConfigBag))
-#define BONOBO_CONFIG_BAG_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST ((k), BONOBO_CONFIG_BAG_TYPE, BonoboConfigBagClass))
-#define BONOBO_IS_CONFIG_BAG(o)	      (G_TYPE_CHECK_INSTANCE_CAST ((o), BONOBO_CONFIG_BAG_TYPE))
-#define BONOBO_IS_CONFIG_BAG_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), BONOBO_CONFIG_BAG_TYPE))
+#define BONOBO_TYPE_CONFIG_BAG        (bonobo_config_bag_get_type ())
+#define BONOBO_CONFIG_BAG_TYPE        BONOBO_TYPE_CONFIG_BAG // deprecated, you should use BONOBO_TYPE_CONFIG_BAG
+#define BONOBO_CONFIG_BAG(o)	      (G_TYPE_CHECK_INSTANCE_CAST ((o), BONOBO_TYPE_CONFIG_BAG, BonoboConfigBag))
+#define BONOBO_CONFIG_BAG_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST ((k), BONOBO_TYPE_CONFIG_BAG, BonoboConfigBagClass))
+#define BONOBO_IS_CONFIG_BAG(o)	      (G_TYPE_CHECK_INSTANCE_CAST ((o), BONOBO_TYPE_CONFIG_BAG))
+#define BONOBO_IS_CONFIG_BAG_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), BONOBO_TYPE_CONFIG_BAG))
 
 typedef struct _BonoboConfigBag        BonoboConfigBag;
 
