@@ -18,7 +18,7 @@ static GObjectClass *parent_class = NULL;
 
 #define CLASS(o) BONOBO_CONFIG_DATABASE_CLASS (G_OBJECT_GET_CLASS (o))
 
-#define PARENT_TYPE (BONOBO_X_OBJECT_TYPE)
+#define PARENT_TYPE (BONOBO_TYPE_X_OBJECT)
 
 #define DATABASE_FROM_SERVANT(servant) \
 (BONOBO_CONFIG_DATABASE (bonobo_object (servant)))
@@ -672,7 +672,7 @@ bonobo_property_bag_server_init (BonoboPropertyBagServer *pb)
 
 BONOBO_TYPE_FUNC_FULL (BonoboPropertyBagServer, 
 		       Bonobo_PropertyBag,
-		       BONOBO_OBJECT_TYPE,
+		       BONOBO_TYPE_OBJECT,
 		       bonobo_property_bag_server);
 
 static void
