@@ -146,28 +146,28 @@ xml_encode_value (xmlNode           *parent,
 
 
 		DO_ENCODE (CORBA_tk_short, "%d", CORBA_short, value, 
-			   ALIGNOF_CORBA_SHORT);
+			   ORBIT_ALIGNOF_CORBA_SHORT);
 		DO_ENCODE (CORBA_tk_ushort, "%u", CORBA_unsigned_short, value,
-			   ALIGNOF_CORBA_SHORT);
+			   ORBIT_ALIGNOF_CORBA_SHORT);
 		DO_ENCODE (CORBA_tk_long, "%d", CORBA_long, value, 
-			   ALIGNOF_CORBA_LONG);
+			   ORBIT_ALIGNOF_CORBA_LONG);
 		DO_ENCODE (CORBA_tk_enum, "%d", CORBA_long, value, 
-			   ALIGNOF_CORBA_LONG);
+			   ORBIT_ALIGNOF_CORBA_LONG);
 		DO_ENCODE (CORBA_tk_ulong, "%u", CORBA_unsigned_long, value, 
-			   ALIGNOF_CORBA_LONG);
+			   ORBIT_ALIGNOF_CORBA_LONG);
 		DO_ENCODE (CORBA_tk_float, "%g", CORBA_float, value, 
-			   ALIGNOF_CORBA_FLOAT);
+			   ORBIT_ALIGNOF_CORBA_FLOAT);
 		DO_ENCODE (CORBA_tk_double, "%g", CORBA_double, value, 
-			   ALIGNOF_CORBA_DOUBLE);
+			   ORBIT_ALIGNOF_CORBA_DOUBLE);
 		DO_ENCODE (CORBA_tk_boolean, "%d", CORBA_boolean, value, 1);
 		DO_ENCODE (CORBA_tk_char, "%d", CORBA_char, value,  1);
 		DO_ENCODE (CORBA_tk_octet, "%d", CORBA_octet, value, 1);
 		DO_ENCODE (CORBA_tk_wchar, "%d", CORBA_wchar, value, 
-			   ALIGNOF_CORBA_SHORT);
+			   ORBIT_ALIGNOF_CORBA_SHORT);
 
 	case CORBA_tk_string:
 	case CORBA_tk_wstring:
-		*value = ALIGN_ADDRESS(*value, ALIGNOF_CORBA_POINTER);
+		*value = ALIGN_ADDRESS(*value, ORBIT_ALIGNOF_CORBA_POINTER);
 		xmlNodeSetContent (node, *(CORBA_char **) *value);
 		*value = ((guchar *)*value) + sizeof (CORBA_char *);
 		break;
@@ -177,16 +177,16 @@ xml_encode_value (xmlNode           *parent,
 		break;
 
 	case CORBA_tk_TypeCode:
-		*value = ALIGN_ADDRESS (*value, ALIGNOF_CORBA_POINTER);
+		*value = ALIGN_ADDRESS (*value, ORBIT_ALIGNOF_CORBA_POINTER);
 		xml_encode_type (node, * (CORBA_TypeCode *) *value, ev);
 		*value = ((guchar *)*value) + sizeof(CORBA_TypeCode);
 		break;
 
 	case CORBA_tk_any:
 		*value = ALIGN_ADDRESS (*value,
-					MAX (ALIGNOF_CORBA_LONG,
-					     MAX (ALIGNOF_CORBA_POINTER, 
-						  ALIGNOF_CORBA_STRUCT)));
+					MAX (ORBIT_ALIGNOF_CORBA_LONG,
+					     MAX (ORBIT_ALIGNOF_CORBA_POINTER, 
+						  ORBIT_ALIGNOF_CORBA_STRUCT)));
 		bonobo_property_bag_xml_encode_any (node, (CORBA_any *) *value,
 						    ev);
 		*value = ((guchar *)*value) + sizeof (CORBA_any);
@@ -197,9 +197,9 @@ xml_encode_value (xmlNode           *parent,
 		gpointer subval;
 
 		*value = ALIGN_ADDRESS (*value,
-					MAX (MAX (ALIGNOF_CORBA_LONG, 
-						  ALIGNOF_CORBA_STRUCT), 
-					     ALIGNOF_CORBA_POINTER));
+					MAX (MAX (ORBIT_ALIGNOF_CORBA_LONG, 
+						  ORBIT_ALIGNOF_CORBA_STRUCT), 
+					     ORBIT_ALIGNOF_CORBA_POINTER));
 
 		snprintf (scratch, 127, "%d", sval->_length);
 		xmlSetProp (node, "length", scratch);
@@ -500,29 +500,29 @@ decode_value (xmlNode           *node,
 		break;
 
 		DO_DECODEI_XML (CORBA_tk_short, "%d", CORBA_short, value, 
-				ALIGNOF_CORBA_SHORT);
+				ORBIT_ALIGNOF_CORBA_SHORT);
 		DO_DECODEI_XML (CORBA_tk_ushort, "%u", CORBA_unsigned_short, 
-				value, ALIGNOF_CORBA_SHORT);
+				value, ORBIT_ALIGNOF_CORBA_SHORT);
 		DO_DECODEI_XML (CORBA_tk_long, "%d", CORBA_long, value, 
-				ALIGNOF_CORBA_LONG);
+				ORBIT_ALIGNOF_CORBA_LONG);
 		DO_DECODEI_XML (CORBA_tk_enum, "%d", CORBA_long, value, 
-				ALIGNOF_CORBA_LONG);
+				ORBIT_ALIGNOF_CORBA_LONG);
 		DO_DECODEI_XML (CORBA_tk_ulong, "%u", CORBA_unsigned_long, 
-				value, ALIGNOF_CORBA_LONG);
+				value, ORBIT_ALIGNOF_CORBA_LONG);
 		DO_DECODEI_XML (CORBA_tk_boolean, "%d", CORBA_boolean, value, 
 				1);
 		DO_DECODEI_XML (CORBA_tk_char, "%d", CORBA_char, value,  1);
 		DO_DECODEI_XML (CORBA_tk_octet, "%d", CORBA_octet, value, 1);
 		DO_DECODEI_XML (CORBA_tk_wchar, "%d", CORBA_wchar, value, 
-				ALIGNOF_CORBA_SHORT);
+				ORBIT_ALIGNOF_CORBA_SHORT);
 		DO_DECODE_XML (CORBA_tk_float, "%g", CORBA_float, value, 
-			       ALIGNOF_CORBA_FLOAT);
+			       ORBIT_ALIGNOF_CORBA_FLOAT);
 		DO_DECODE_XML (CORBA_tk_double, "%lg", CORBA_double, value, 
-			       ALIGNOF_CORBA_DOUBLE);
+			       ORBIT_ALIGNOF_CORBA_DOUBLE);
 
 	case CORBA_tk_string:
 	case CORBA_tk_wstring:
-		*value = ALIGN_ADDRESS (*value, ALIGNOF_CORBA_POINTER);
+		*value = ALIGN_ADDRESS (*value, ORBIT_ALIGNOF_CORBA_POINTER);
 		if (scratch)
 			*(CORBA_char **) *value = CORBA_string_dup (scratch);
 		else 
@@ -535,16 +535,16 @@ decode_value (xmlNode           *node,
 		break;
 
 	case CORBA_tk_TypeCode:
-		*value = ALIGN_ADDRESS (*value, ALIGNOF_CORBA_POINTER);
+		*value = ALIGN_ADDRESS (*value, ORBIT_ALIGNOF_CORBA_POINTER);
 		*(CORBA_TypeCode *) *value = decode_type (node, ev);
 		*value = ((guchar *) *value) + sizeof (CORBA_TypeCode);
 		break;
 
 	case CORBA_tk_any:
 		*value = ALIGN_ADDRESS (*value,
-					MAX (ALIGNOF_CORBA_LONG,
-					     MAX (ALIGNOF_CORBA_POINTER, 
-						  ALIGNOF_CORBA_STRUCT)));
+					MAX (ORBIT_ALIGNOF_CORBA_LONG,
+					     MAX (ORBIT_ALIGNOF_CORBA_POINTER, 
+						  ORBIT_ALIGNOF_CORBA_STRUCT)));
 		*(CORBA_any **)*value = 
 			bonobo_property_bag_xml_decode_any (node, ev);
 		*value = ((guchar *) *value) + sizeof (CORBA_any);
@@ -569,9 +569,9 @@ decode_value (xmlNode           *node,
 			tc->subtypes [0], sval->_length) : NULL;
 
 		*value = ALIGN_ADDRESS (*value,
-					MAX (MAX (ALIGNOF_CORBA_LONG, 
-						  ALIGNOF_CORBA_STRUCT), 
-					     ALIGNOF_CORBA_POINTER));
+					MAX (MAX (ORBIT_ALIGNOF_CORBA_LONG, 
+						  ORBIT_ALIGNOF_CORBA_STRUCT), 
+					     ORBIT_ALIGNOF_CORBA_POINTER));
 
 		subval = sval->_buffer;
 		i = 0;
@@ -724,17 +724,17 @@ encode_value (char             **buffer,
 		break;
 
 		ENCODE_TO_STRING (CORBA_tk_short,  "%d", CORBA_short, value, 
-				  ALIGNOF_CORBA_SHORT);
+				  ORBIT_ALIGNOF_CORBA_SHORT);
 		ENCODE_TO_STRING (CORBA_tk_ushort, "%u", CORBA_unsigned_short,
-				  value, ALIGNOF_CORBA_SHORT);
+				  value, ORBIT_ALIGNOF_CORBA_SHORT);
 		ENCODE_TO_STRING (CORBA_tk_long, "%d", CORBA_long, value, 
-				  ALIGNOF_CORBA_LONG);
+				  ORBIT_ALIGNOF_CORBA_LONG);
 		ENCODE_TO_STRING (CORBA_tk_ulong,  "%u", CORBA_unsigned_long, 
-				  value, ALIGNOF_CORBA_LONG);
+				  value, ORBIT_ALIGNOF_CORBA_LONG);
 		ENCODE_TO_STRING (CORBA_tk_float, "%g", CORBA_float, value, 
-				  ALIGNOF_CORBA_FLOAT);
+				  ORBIT_ALIGNOF_CORBA_FLOAT);
 		ENCODE_TO_STRING (CORBA_tk_double, "%g", CORBA_double, value, 
-				  ALIGNOF_CORBA_DOUBLE);
+				  ORBIT_ALIGNOF_CORBA_DOUBLE);
 		ENCODE_TO_STRING (CORBA_tk_boolean, "%d", CORBA_boolean, 
 				  value, 1);
 		ENCODE_TO_STRING (CORBA_tk_char, "%d", CORBA_char, value, 1);
@@ -742,16 +742,16 @@ encode_value (char             **buffer,
 		ENCODE_TO_STRING (CORBA_tk_octet, "%d", CORBA_octet, value, 1);
 
 		ENCODE_TO_STRING (CORBA_tk_wchar, "%d", CORBA_wchar, value, 
-				  ALIGNOF_CORBA_SHORT);
+				  ORBIT_ALIGNOF_CORBA_SHORT);
 
 	case CORBA_tk_enum:
-		*value = ALIGN_ADDRESS (*value,  ALIGNOF_CORBA_LONG);
+		*value = ALIGN_ADDRESS (*value,  ORBIT_ALIGNOF_CORBA_LONG);
 		ADD_STRING (tc->subnames[*(CORBA_long *)*value]);
 		*value = ((guchar *)*value) + sizeof(CORBA_long);
 		break;
 	case CORBA_tk_string:
 	case CORBA_tk_wstring:
-		*value = ALIGN_ADDRESS(*value, ALIGNOF_CORBA_POINTER);
+		*value = ALIGN_ADDRESS(*value, ORBIT_ALIGNOF_CORBA_POINTER);
 		ADD_STRING ("\"");
 		l = strlen (*(CORBA_char **) *value); 
 		memcpy (*buffer, *(CORBA_char **) *value, l + 1);
@@ -764,9 +764,9 @@ encode_value (char             **buffer,
 		CORBA_sequence_CORBA_octet *sval;
 		gpointer subval;
 
-		*value = ALIGN_ADDRESS (*value, MAX(MAX(ALIGNOF_CORBA_LONG, 
-							ALIGNOF_CORBA_STRUCT),
-						    ALIGNOF_CORBA_POINTER));
+		*value = ALIGN_ADDRESS (*value, MAX(MAX(ORBIT_ALIGNOF_CORBA_LONG, 
+							ORBIT_ALIGNOF_CORBA_STRUCT),
+						    ORBIT_ALIGNOF_CORBA_POINTER));
 
 		sval = *value;
 		subval = sval->_buffer;
