@@ -15,12 +15,13 @@
 
 G_BEGIN_DECLS
  
-#define BONOBO_PROPERTY_FRAME_TYPE        (bonobo_property_frame_get_type ())
-#define BONOBO_PROPERTY_FRAME(o)          (GTK_CHECK_CAST ((o), BONOBO_PROPERTY_FRAME_TYPE, BonoboPropertyFrame))
-#define BONOBO_PROPERTY_FRAME_CLASS(k)    (GTK_CHECK_CLASS_CAST((k), BONOBO_PROPERTY_FRAME_TYPE, BonoboPropertyFrameClass))
+#define BONOBO_TYPE_PROPERTY_FRAME        (bonobo_property_frame_get_type ())
+#define BONOBO_PROPERTY_FRAME_TYPE        BONOBO_TYPE_PROPERTY_FRAME // deprecated, you should use BONOBO_TYPE_PROPERTY_FRAME
+#define BONOBO_PROPERTY_FRAME(o)          (GTK_CHECK_CAST ((o), BONOBO_TYPE_PROPERTY_FRAME, BonoboPropertyFrame))
+#define BONOBO_PROPERTY_FRAME_CLASS(k)    (GTK_CHECK_CLASS_CAST((k), BONOBO_TYPE_PROPERTY_FRAME, BonoboPropertyFrameClass))
 
-#define BONOBO_IS_PROPERTY_FRAME(o)       (GTK_CHECK_TYPE ((o), BONOBO_PROPERTY_FRAME_TYPE))
-#define BONOBO_IS_PROPERTY_FRAME_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), BONOBO_PROPERTY_FRAME_TYPE))
+#define BONOBO_IS_PROPERTY_FRAME(o)       (GTK_CHECK_TYPE ((o), BONOBO_TYPE_PROPERTY_FRAME))
+#define BONOBO_IS_PROPERTY_FRAME_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), BONOBO_TYPE_PROPERTY_FRAME))
 
 typedef struct _BonoboPropertyFrame         BonoboPropertyFrame;
 typedef struct _BonoboPropertyFrameClass    BonoboPropertyFrameClass;
