@@ -29,7 +29,7 @@ static GObjectClass *parent_class = NULL;
 
 #define CLASS(o) BONOBO_CONFIG_DITEM_CLASS (G_OBJECT_GET_CLASS (o))
 
-#define PARENT_TYPE BONOBO_CONFIG_DATABASE_TYPE
+#define PARENT_TYPE BONOBO_TYPE_CONFIG_DATABASE
 #define FLUSH_INTERVAL 30 /* 30 seconds */
 
 typedef struct _BonoboConfigDItemKey		BonoboConfigDItemKey;
@@ -1854,7 +1854,7 @@ bonobo_config_ditem_new (const char *filename, Bonobo_ConfigDatabase parent_db,
 		return CORBA_OBJECT_NIL;
 	}
 
-	if (!(ditem = g_object_new (BONOBO_CONFIG_DITEM_TYPE, NULL))) {
+	if (!(ditem = g_object_new (BONOBO_TYPE_CONFIG_DITEM, NULL))) {
 		bonobo_config_ditem_free_directory (dir);
 		g_free (real_name);
 		return CORBA_OBJECT_NIL;
