@@ -18,7 +18,7 @@ static GObjectClass *parent_class = NULL;
 
 #define CLASS(o) BONOBO_CONFIG_GCONFDB_CLASS (G_OBJECT_GET_CLASS (o))
 
-#define PARENT_TYPE BONOBO_CONFIG_DATABASE_TYPE
+#define PARENT_TYPE BONOBO_TYPE_CONFIG_DATABASE
 
 #define ANY_PREFIX "%CORBA:ANY%"
 
@@ -458,7 +458,7 @@ bonobo_config_gconfdb_new ()
 	if (!(client = gconf_client_get_default ()))
 		return NULL;
 
-	if (!(gconfdb = g_object_new (BONOBO_CONFIG_GCONFDB_TYPE, NULL)))
+	if (!(gconfdb = g_object_new (BONOBO_TYPE_CONFIG_GCONFDB, NULL)))
 		return CORBA_OBJECT_NIL;
 
 	gconfdb->client = client;
