@@ -15,11 +15,12 @@
 
 G_BEGIN_DECLS
 
-#define BONOBO_CONFIG_GCONFDB_TYPE        (bonobo_config_gconfdb_get_type ())
-#define BONOBO_CONFIG_GCONFDB(o)	  (G_TYPE_CHECK_INSTANCE_CAST ((o), BONOBO_CONFIG_GCONFDB_TYPE, BonoboConfigGConfDB))
-#define BONOBO_CONFIG_GCONFDB_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST ((k), BONOBO_CONFIG_GCONFDB_TYPE, BonoboConfigGConfDBClass))
-#define BONOBO_IS_CONFIG_GCONFDB(o)       (G_TYPE_CHECK_INSTANCE_CAST ((o), BONOBO_CONFIG_GCONFDB_TYPE))
-#define BONOBO_IS_CONFIG_GCONFDB_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), BONOBO_CONFIG_GCONFDB_TYPE))
+#define BONOBO_TYPE_CONFIG_GCONFDB        (bonobo_config_gconfdb_get_type ())
+#define BONOBO_CONFIG_GCONFDB_TYPE        BONOBO_TYPE_CONFIG_GCONFDB // deprecated, you should use BONOBO_TYPE_CONFIG_GCONFDB
+#define BONOBO_CONFIG_GCONFDB(o)	  (G_TYPE_CHECK_INSTANCE_CAST ((o), BONOBO_TYPE_CONFIG_GCONFDB, BonoboConfigGConfDB))
+#define BONOBO_CONFIG_GCONFDB_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST ((k), BONOBO_TYPE_CONFIG_GCONFDB, BonoboConfigGConfDBClass))
+#define BONOBO_IS_CONFIG_GCONFDB(o)       (G_TYPE_CHECK_INSTANCE_CAST ((o), BONOBO_TYPE_CONFIG_GCONFDB))
+#define BONOBO_IS_CONFIG_GCONFDB_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), BONOBO_TYPE_CONFIG_GCONFDB))
 
 typedef struct {
 	BonoboConfigDatabase  base;
